@@ -553,101 +553,94 @@
 (define d-GetOnsetTime d-GetMidiOnTime)  ;;;was a duplicate, not used by Denemo
 ; DenemoConvert
 (define (DenemoConvert)
-(define MidiNoteStarts (make-vector 256 #f))
-
-(defstruct Note name start duration)
-(define Notes '())
-
-(if (d-RewindRecordedMidi)
-    (let loop ((note #f)(tick 0))
-      (set! note (d-GetRecordedMidiNote))
-      (if note
-      (begin
-        (set! tick (d-GetRecordedMidiOnTick))
-        (if (< tick 0)
-        (let ((on (vector-ref MidiNoteStarts note)))
-          (if on
-              (begin 
-            (set! Notes (cons (list (make-Note 'name note 'start on 'duration (- (- tick) on))) Notes))
-            (vector-set! MidiNoteStarts note #f)    
-            (loop note tick))
-              (format #t "An off with no On\n")))
-        (let ((on (vector-ref MidiNoteStarts note)))
-          (if on
-              (format #t "An on when already on\n")
+    (define MidiNoteStarts (make-vector 256 #f))
+    (defstruct Note name start duration)
+    (define Notes '())
+    (if (d-RewindRecordedMidi)
+        (let loop ((note #f)(tick 0))
+          (set! note (d-GetRecordedMidiNote)) ;(disp "note is " note "\n")
+          (if note
               (begin
-            (vector-set! MidiNoteStarts note tick)
-            (loop note tick)
-        )))))
-      (begin         ;;;;;; finished processing the notes
-        (if (> (length Notes) 0)
-        (let ()
-            (define (add-note note)
-              (if (Note? note)
-              (begin
-              (eval-string (string-append "(d-InsertNoteInChord \"" (d-GetNoteForMidiKey (Note.name note)) "\")")))
-              (format #t "\tNo note to add note ~a ~a to\n" (Note.name note) (Note.duration note))))
-            
-            (define (insert-note name dur)
-              (let ((base (duration::GuessBaseNoteInTicks dur)))
-(format #t "have ~a ~a \n" base dur)
-            (if base
-                (begin
-                  (if (> (- dur base) (- (* 2 base) dur))
-                  (set! base (* base 2)))
-                  (begin 
-                ;(format #t "Create note ~a ~a\n"  (d-GetNoteForMidiKey name)   (duration::ticks->denemo base))
-                (eval-string (string-append  "(d-Insert" (duration::ticks->denemo base)")"))
-                (d-PutNoteName (d-GetNoteForMidiKey name)))))))
-            
-        
-            (set! Notes (reverse Notes))
-     
-;;;;;; change the list of Notes into a list of chords
-            (let loop ((index 0))
-
-;;;;;;;;;;; overlap decides if two notes should be a chord   
-              (define (overlap n1 n2)
-            (if (list? n1)
-                (set! n1 (car n1)))
-            (< (abs (- (Note.start n1) (Note.start n2))) 50))
-;;;;;;;;;;;;;;;;;; end of overlap
-              
-                    ;(format #t "Number of notes ~a\n" index)         
-              (let ((note1 (list-ref Notes index))
-                (note2 #f))
-            (if (> (length Notes) (+ 1 index))
-                (begin
-                  (set! note2 (list-ref Notes (+ 1 index)))
-                  (if (overlap note1 (car note2))
-                  (begin
-                    (list-set! Notes index (cons (car note2) note1))
-                    (set! Notes (delq note2 Notes)))
-                  (begin
-                    ;(list-set! Notes index (list note1))
-                    (set! index (+ index 1))))
-                  (loop index))))) ;;;;;;; end of changing Notes to list of chords
+                (set! tick (d-GetRecordedMidiOnTick)) ;(disp "tick is " tick "\n")
+                (if (< tick 0) ;;; note OFF
+                    (let ((on (vector-ref MidiNoteStarts note)))
+                      (if on
+                          (begin 
+                            (set! Notes (cons (list (make-Note 'name note 'start on 'duration (- (- tick) on))) Notes))
+                            (vector-set! MidiNoteStarts note #f)    
+                            (loop note tick))
+                          (disp "An off with no On\n")))
+                    (let ((on (vector-ref MidiNoteStarts note))) ;;;note ON
+                      (if on
+                          (disp "An on when already on\n")
+                          (begin
+                            (vector-set! MidiNoteStarts note tick)
+                            (loop note tick))))))
+              (begin         ;;;;;; finished processing the notes
+                (if (> (length Notes) 0)
+                        (let ()
+                            (define (add-note note)
+                              (if (Note? note)
+                                  (begin
+                                    (eval-string (string-append "(d-InsertNoteInChord \"" (d-GetNoteForMidiKey (Note.name note)) "\")")))
+                                  (disp "\tNo note to add note ~a ~a to\n" (Note.name note) (Note.duration note))))
+                            (define (insert-note name dur)
+                              (let ((base (duration::GuessBaseNoteInTicks dur)))
+                                (format #t "have ~a ~a \n" base dur)
+                                (if base
+                                    (begin
+                                      (if (> (- dur base) (- (* 2 base) dur))
+                                      (set! base (* base 2)))
+                                      (begin 
+                                    ;(format #t "Create note ~a ~a\n"  (d-GetNoteForMidiKey name)   (duration::ticks->denemo base))
+                                    (eval-string (string-append  "(d-Insert" (duration::ticks->denemo base)")"))
+                                    (d-PutNoteName (d-GetNoteForMidiKey name)))))))
+                                    
+                            (set! Notes (reverse Notes))
+                            ;;;;;; change the list of Notes into a list of chords
+                            (let loop ((index 0))
+                                ;;;;;;;;;;; overlap decides if two notes should be a chord   
+                              (define (overlap n1 n2)
+                                (if (list? n1)
+                                    (set! n1 (car n1)))
+                                (< (abs (- (Note.start n1) (Note.start n2))) 50))
+                                ;;;;;;;;;;;;;;;;;; end of overlap
+                              
+                                    ;(format #t "Number of notes ~a\n" index)         
+                              (let ((note1 (list-ref Notes index))(note2 #f))
+                                (if (> (length Notes) (+ 1 index))
+                                    (begin
+                                      (set! note2 (list-ref Notes (+ 1 index)))
+                                      (if (overlap note1 (car note2))
+                                      (begin
+                                        (list-set! Notes index (cons (car note2) note1))
+                                        (set! Notes (delq note2 Notes)))
+                                      (begin
+                                        ;(list-set! Notes index (list note1))
+                                        (set! index (+ index 1))))
+                                      (loop index))))) ;;;;;;; end of changing Notes to list of chords
 
 
-;;;loop through the chords, getting a good duration value, the duration from one to the next and inserting
-            (let loop ((index 0))
-              (if (> (length Notes) (+ 1 index))
-              (let ((chord1 (list-ref Notes index))
-                (chord2 #f)
-                (duration #f))
-                (if (> (length Notes) (+ 1 index))
-                 (begin
-                  (set! chord2 (list-ref Notes (+ 1 index)))
-                  (set! duration (- (Note.start (car chord2)) (Note.start (car chord1))))
-                  (format #t "With duration ~a\n" duration)
-                  (insert-note (Note.name (car chord1)) duration)
-                   (for-each  add-note (cdr chord1))
-                   (set! index (+ index 1))
-                   (loop index))
-                 (insert-note (Note.name (car chord1)) (Note.duration (car chord1)))))))
-        
-            (format #t "End of processing\n"))))));;;;;if rewind succeeded
-        (format #t "No notes found in recording\n")))
+                            ;;;loop through the chords, getting a good duration value, the duration from one to the next and inserting
+                            (let loop ((index 0))
+                              (if (> (length Notes) (+ 1 index))
+                              (let ((chord1 (list-ref Notes index))
+                                    (chord2 #f)
+                                    (duration #f))
+                                (if (> (length Notes) (+ 1 index))
+                                    (begin
+                                        (set! chord2 (list-ref Notes (+ 1 index)))
+                                        (set! duration (- (Note.start (car chord2)) (Note.start (car chord1))))
+                                        (format #t "With duration ~a\n" duration)
+                                        (insert-note (Note.name (car chord1)) duration)
+                                        (for-each  add-note (cdr chord1))
+                                        (set! index (+ index 1))
+                                        (loop index))
+                                    (insert-note (Note.name (car chord1)) (Note.duration (car chord1)))))))
+                        
+                            (format #t "End of processing\n"))))));;;;;if rewind succeeded
+            (format #t "No notes found in recording\n")))
+
 
 
 ;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1438,3 +1431,45 @@
                 (d-DirectivePut-paper-data tag data)
                 (d-DirectivePut-paper-postfix tag (string-append type ".basic-distance =  " data "\n"))))))
                 
+;;;;edit staff, called from tools icon at start of staff
+(define (EditStaff)
+        (let* ((num (number->string (d-GetStaff)))(choice (RadioBoxMenu 
+            (if  (> (d-StaffMasterVolume) 0)
+                (cons (string-append (_ "Mute Staff") " " num) 'mute)
+                (cons  (string-append (_ "Unmute Staff") " " num) 'mute))
+            (if (d-Directive-staff? "NonPrintingStaff")
+                (cons  (string-append (_ "(Print) Show Staff") " " num) 'show)
+                (cons  (string-append (_ "(Print) Hide Staff") " " num) 'show))
+                
+            (if (d-StaffHidden)
+                (cons  (string-append (_ "(Display) Show Staff") " " num) 'display)
+                (cons  (string-append (_ "(Display) Hide Staff") " " num) 'display))
+                
+            (cons (_ "Built-in Staff Properties") 'editor))))
+        (case choice
+            ((mute) (d-MuteStaff))
+            ((show) (d-NonPrintingStaff))
+            ((display) (d-ToggleCurrentStaffDisplay))
+            ((editor) (d-StaffProperties)))))
+;;;;edit staff, called from tools icon at start of staff
+(define (EditMovement)
+        (let* ((choice (RadioBoxMenu 
+            (cons (_ "Help") 'help)
+            (cons (_ "Mute Staffs") 'mute)
+            (cons (_ "(Display) Show All Staffs") 'show)
+            (cons (_ "(Display) Hide All Other Staffs") 'hide)
+            (cons (_ "Movement Editor") 'editor))))
+        (case choice
+            ((help) (d-InfoDialog (_ "This sets the visibility/mute and other properties for the whole movement")))
+            ((mute) (d-MuteStaffs))
+            ((show) (StaffsVisibility #t))
+            ((hide)  (StaffsVisibility #f))
+            ((editor) (d-EditMovementProperties)))))
+;;;
+(define (StaffsVisibility bool)
+(d-PushPosition)
+(while (d-MoveToStaffUp))
+(let loop () (d-StaffHidden (not bool))
+    (if (d-MoveToStaffDown) 
+        (loop)))
+(d-PopPosition))      
