@@ -1187,6 +1187,28 @@ struct DenemoRoot
   gint height;
   gboolean maximized;
   gint color;/**< the color of the background */
+  gboolean hovering_over_margin_up;
+  gboolean hovering_over_margin_down;
+  gboolean hovering_over_brace;
+  gboolean hovering_over_partname;
+  gboolean hovering_over_clef;
+  gboolean hovering_over_timesig;
+  gboolean hovering_over_keysharpen;
+  gboolean hovering_over_keyflatten;
+  gboolean hovering_over_movement;
+  gboolean hovering_over_left_arrow;
+  gboolean hovering_over_right_arrow;
+  GList *object_hovering_over;
+  
+  GdkCursor *GDK_LEFT_PTR;
+  GdkCursor *GDK_SB_V_DOUBLE_ARROW;
+  GdkCursor *GDK_SB_H_DOUBLE_ARROW;
+  GdkCursor *GDK_X_CURSOR;
+  GdkCursor *GDK_TARGET;
+  
+  
+  
+  GList *hidden_staff_heights; /**< list of y positions of markers in display for hidden staff positions */
   keymap *map; /**< pointer to data describing each of the Denemo commands and their keyboard shortcuts */
   gchar *last_merged_command;/**<filename of last command merged into the menu system */
   gint last_keyval, last_keystate;/**< most recent keypress which successfully invoked a command */
