@@ -241,7 +241,7 @@ audio_initialize (DenemoPrefs * config)
 , RUBBERBAND_QUEUE_SIZE
 #endif
 );
-  event_queues[MIDI_BACKEND] = event_queue_new (PLAYBACK_QUEUE_SIZE, IMMEDIATE_QUEUE_SIZE, INPUT_QUEUE_SIZE, 0  
+  event_queues[MIDI_BACKEND] = event_queue_new (PLAYBACK_QUEUE_SIZE, IMMEDIATE_QUEUE_SIZE, INPUT_QUEUE_SIZE, 0
 #ifdef _HAVE_RUBBERBAND_
 , 0
 #endif
@@ -334,7 +334,7 @@ redraw_playhead_callback (gpointer data)
 static gboolean do_handle_midi_event (gchar *data) {
   handle_midi_event (data);
   g_free(data);
-  return FALSE;  
+  return FALSE;
 }
 static gboolean
 handle_midi_event_callback (gpointer data)
@@ -485,8 +485,11 @@ queue_thread_func (gpointer data)
         {
           float sample[2];      //two channels assumed FIXME
           //FIXME I think this will drop samples if they can't be put in the queue, should find if there is space for a sample before getting it.
+#ifdef DISABLE_AUBIO
+#else
           while (get_audio_sample (sample) && write_sample_to_mixer_queue (AUDIO_BACKEND, sample))
             ;
+#endif
         }
 
 
@@ -596,7 +599,7 @@ void
 audio_play (void)
 {
   reset_mixer_queue (AUDIO_BACKEND);
-#ifdef _HAVE_RUBBERBAND_  
+#ifdef _HAVE_RUBBERBAND_
   reset_rubberband_queue (AUDIO_BACKEND);
 #endif
   playback_start_time = get_start_time ();
@@ -606,7 +609,7 @@ audio_play (void)
 }
 
 void
-midi_stop ()
+midi_stop (void)
 {
   g_message ("Stopping playback");
 
@@ -614,13 +617,17 @@ midi_stop ()
   get_backend (MIDI_BACKEND)->stop_playing ();
 
   stop_playing ();
+#ifdef DISABLE_AUBIO
+#else
   stop_audio_playing ();
+#endif
   reset_playback_queue (AUDIO_BACKEND);
   reset_playback_queue (MIDI_BACKEND);
   reset_mixer_queue (AUDIO_BACKEND);
-#ifdef _HAVE_RUBBERBAND_  
+#ifdef _HAVE_RUBBERBAND_
   reset_rubberband_queue (AUDIO_BACKEND);
 #endif
+   gtk_widget_queue_draw (Denemo.playbackview);
 }
 
 
