@@ -183,17 +183,13 @@ set_width_to_work_with (DenemoProject * gui)
     {
       DenemoMovement *si = ((DenemoMovement *) g->data);
 
-#if 0
-      si->widthtoworkwith = (double) (Denemo.scorearea->allocation.width * ((int) (1 / si->system_height)) / si->zoom - (RIGHT_MARGIN + (gui->leftmargin+35) + si->maxkeywidth + SPACE_FOR_TIME));
-#else
       //the total line length for drawing DenemoObjects onto the screen
       // this length will be divided amongst the systems (line).
       // This length is in "pixels", the Denemo unit of display, which corresponds to a screen pixel when zoom ==1.0
+      //this value often does not leave enough room for the right_arrow "button" which cannot then be accessed, subtracting say 10 off the value wastes space generally but alleviates the problem...
       si->widthtoworkwith = (gint) ((get_widget_width (Denemo.scorearea) / si->zoom - (RIGHT_MARGIN + (gui->leftmargin+35) + si->maxkeywidth + SPACE_FOR_TIME)) * ((int) (1 / si->system_height)));
-#endif
 
-
-      //g_debug("Width %d from num systems%d\n", si->widthtoworkwith, ((int)(1/si->system_height )));
+     // g_print("Width %d from num systems%d\n", si->widthtoworkwith, ((int)(1/si->system_height )));
     }
 }
 
