@@ -119,12 +119,13 @@ delete_figured_bass (GtkAction * action, DenemoScriptParam * param)
   if (confirm ("Figured Bass Deletion", "Delete all figured bass markings from this staff?"))
     {
       thestaff->hasfigures = FALSE;
+      gui->movement->has_figures = FALSE;
       score_status (gui, TRUE);
       measurenode *curmeasure;
-      for (curmeasure = thestaff->measures; curmeasure; curmeasure = curmeasure->next)
+      for (curmeasure = thestaff->themeasures; curmeasure; curmeasure = curmeasure->next)
         {
           objnode *curobj;
-          for (curobj = curmeasure->data; curobj; curobj = curobj->next)
+          for (curobj = ((DenemoMeasure*)curmeasure->data)->objects; curobj; curobj = curobj->next)
             {
               DenemoObject *curObj = (DenemoObject *) curobj->data;
               if (curObj && curObj->type == CHORD)
@@ -154,10 +155,10 @@ show_figured_bass (GtkAction * action, DenemoScriptParam * param)
   DenemoProject *gui = Denemo.project;
   DenemoStaff *thestaff = (DenemoStaff *) gui->movement->currentstaff->data;
   measurenode *curmeasure;
-  for (curmeasure = thestaff->measures; curmeasure; curmeasure = curmeasure->next)
+  for (curmeasure = thestaff->themeasures; curmeasure; curmeasure = curmeasure->next)
     {
       objnode *curobj;
-      for (curobj = curmeasure->data; curobj; curobj = curobj->next)
+      for (curobj = ((DenemoMeasure*)curmeasure->data)->objects; curobj; curobj = curobj->next)
         {
           DenemoObject *curObj = (DenemoObject *) curobj->data;
           if (curObj && curObj->type == CHORD)
