@@ -26,7 +26,7 @@
 
 /**
  * Adds measures to the score at given position, and returns the
- * measurenode * to the first one in currentstaff 
+ * measurenode * to the first one in currentstaff
  * @param si the scoreinfo structure
  * @param pos position in staff to insert measures
  * @param nummeasures number of measures to insert
@@ -39,7 +39,8 @@ addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
   staffnode *curstaff;
   guint i;
   objnode *barlinenode = NULL;
-
+  if(all)
+        stage_undo (si, ACTION_STAGE_END);
   for (i = 0; i < nummeasures; i++)
     {
       if (all)
@@ -47,16 +48,16 @@ addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
           gint j;
           for (j = 1, curstaff = si->thescore; curstaff; j++, curstaff = curstaff->next)
             {
-              store_for_undo_measure_insert (si, j, pos);
+              store_for_undo_measure_create (si, j, pos);
               barlinenode = g_malloc0 (sizeof (DenemoMeasure)); //use NULL  originally
               ((DenemoStaff *) curstaff->data)->themeasures = g_list_insert (staff_first_measure_node (curstaff), barlinenode, pos);
               ((DenemoStaff *) curstaff->data)->nummeasures++;
             }
-            
+
         }
       else
         {
-          store_for_undo_measure_insert (si, si->currentstaffnum, pos);
+          store_for_undo_measure_create (si, si->currentstaffnum, pos);
            barlinenode = g_malloc0 (sizeof (DenemoMeasure)); //use NULL  originally
           ((DenemoStaff *) si->currentstaff->data)->themeasures = g_list_insert (staff_first_measure_node (si->currentstaff), barlinenode, pos);
           ((DenemoStaff *) si->currentstaff->data)->nummeasures++;
@@ -75,8 +76,8 @@ addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
 
 
     }
-    
-    
+
+
     if (all)
         cache_all();
     else
@@ -87,6 +88,9 @@ addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
  // score_status(Denemo.project, TRUE);
 //check not returning NULL!!!!
   si->cursoroffend = FALSE;//This was left to the drawing routine to set, but it can happen that no draw occurs before the value is needed.
+
+  if(all)
+        stage_undo (si, ACTION_STAGE_START);
   if (ret)
     return ret;
   g_warning ("Add measures was going to return NULL");
@@ -109,11 +113,11 @@ freeit_object (gpointer data, gpointer user_data)
 }
 
 /**
- * Free a measures objects 
+ * Free a measures objects
  *
  */
 void
-freeobjlist (gpointer data, gpointer user_data)
+freeobjlist (gpointer data)
 {
   objnode *delobjs = (objnode *) data;
   if (delobjs)
@@ -125,7 +129,26 @@ freeobjlist (gpointer data, gpointer user_data)
     }
 }
 
+DenemoMeasure *
+clone_measure (DenemoMeasure* m)
+{ GList *g;
+   DenemoMeasure *ret = g_malloc0 (sizeof (DenemoMeasure));
+   memcpy (ret, m, sizeof (DenemoMeasure));
+   ret->objects = NULL;
+   for (g=m->objects;g;g=g->next)
+    ret->objects = g_list_append (ret->objects, dnm_clone_object (g->data));
+//the cache values will need recalculating depending on how the clone is used.
+    return ret;
+}
 
+void
+free_measure (DenemoMeasure *m)
+{
+  GList *g;
+   for (g=m->objects;g;g=g->next)
+     freeobjlist (g);
+  m->objects = NULL;
+}
 /**
  * staffremovemeasures
  * Contains common code to remove a measure from a staff
@@ -138,7 +161,7 @@ void
 staffremovemeasures (staffnode * curstaff, guint pos)
 {
   //g_debug ("In Staffremovemeasures\n");
-  take_snapshot ();
+  DenemoMovement *si = Denemo.project->movement;
   measurenode *firstmeasure;
   measurenode *delmeasure;
 
@@ -147,22 +170,40 @@ staffremovemeasures (staffnode * curstaff, guint pos)
   if (delmeasure)
     {
 
-      //  g_debug ("Firstmeasure %x\t DelMeasure %x \t Position\n",
-      //       firstmeasure, delmeasure, pos);
+          //  g_debug ("Firstmeasure %x\t DelMeasure %x \t Position\n",
+          //       firstmeasure, delmeasure, pos);
 
 
-      freeobjlist (((DenemoMeasure*)delmeasure->data)->objects, NULL);
-      ((DenemoStaff *) curstaff->data)->themeasures = g_list_remove_link (firstmeasure, delmeasure); //FIXME DANGER
-      g_free ((DenemoMeasure*)delmeasure->data);
-      g_list_free_1 (delmeasure);
+        DenemoUndoData *undo;
+        if (!si->undo_guard)
+            {
+              undo = (DenemoUndoData *) g_malloc (sizeof (DenemoUndoData));
+              undo->object = clone_measure ((DenemoMeasure*)delmeasure->data);
+            }
+       // freeobjlist (((DenemoMeasure*)delmeasure->data)->objects, NULL);
 
-      ((DenemoStaff *) curstaff->data)->nummeasures--;
+        free_measure (delmeasure->data);
+        ((DenemoStaff *) curstaff->data)->themeasures = g_list_remove_link (firstmeasure, delmeasure); //FIXME DANGER
+        g_free ((DenemoMeasure*)delmeasure->data);
+        g_list_free_1 (delmeasure);
+        ((DenemoStaff *) curstaff->data)->nummeasures--;
+        if ( ((DenemoStaff *) curstaff->data)->themeasures != NULL)
+            {//if the removed measures have a clef change in them the noteheights may need to change so...
+            cache_staff (curstaff);
+            staff_fix_note_heights (curstaff->data);
+            }
+        if (!si->undo_guard)
+            {
+              get_position (si, &undo->position);
+              //!!!!!!!! that is setting the cursor position
+                undo->position.staff = 1 + g_list_position (si->thescore, curstaff);
+                g_print ("Setting staff %d\n", undo->position.staff);
+              undo->action = ACTION_MEASURE_DELETE;
+              update_undo_info (si, undo);
+            }
     }
- if ( ((DenemoStaff *) curstaff->data)->themeasures == NULL)
-    return;
-//if the removed measures have a clef change in them the noteheights may need to change so...  
-  cache_staff (curstaff);
-  staff_fix_note_heights (curstaff->data);
+ else
+    g_warning ("Request to delete non-existent measure %d", pos);
 }
 
 /**
@@ -185,6 +226,8 @@ removemeasures (DenemoMovement * si, guint pos, guint nummeasures, gboolean all)
 
   if (nummeasures <= g_list_length (staff_first_measure_node ((staffnode *) si->currentstaff)) - pos)
     {
+      if(all)
+        stage_undo (si, ACTION_STAGE_END);
       for (i = 0; i < nummeasures; i++)
         {
           totalmeasures = 0;
@@ -215,6 +258,8 @@ removemeasures (DenemoMovement * si, guint pos, guint nummeasures, gboolean all)
         }
       set_measure_transition (20, all);
       all?  cache_all (): cache_staff (si->currentstaff);
+      if(all)
+        stage_undo (si, ACTION_STAGE_START);
     }
   else
     {
@@ -236,7 +281,7 @@ removemeasures (DenemoMovement * si, guint pos, guint nummeasures, gboolean all)
 
 /**
  * This function calculates the number of ticks per beat in a given
- * time signature 
+ * time signature
  */
 gint
 calcticksperbeat (gint time1, gint time2)
@@ -282,7 +327,7 @@ is_end_grace (objnode * curobjnode)
  *
  * It works out that this function can be called wherever
  * calculatebeamsandstemdirs is invoked, and would share code besides, so
- * that's precisely where it is invoked 
+ * that's precisely where it is invoked
  */
 static void
 settickvalsinmeasure (objnode * theobjs)
@@ -316,7 +361,7 @@ settickvalsinmeasure (objnode * theobjs)
                     theobj->durinticks = 0;
                 }
 
-                
+
             }
           else
             {
@@ -364,7 +409,7 @@ settickvalsinmeasure (objnode * theobjs)
 /**
  * This function simply sets stem directions. It probably deals with
  * staves that have a fixed stem direction inefficiently, but this was
- * the easiest way to add things to the existing code. 
+ * the easiest way to add things to the existing code.
  */
 static void
 setsdir (objnode * starter, objnode * ender, gint beamgroup_sum, gint beamgroup_number, gint beamgroup_highest, gint beamgroup_lowest, gint clef, gint stem_directive)
@@ -442,8 +487,8 @@ setsdir (objnode * starter, objnode * ender, gint beamgroup_sum, gint beamgroup_
   */
 void
 calculatebeamsandstemdirs (DenemoMeasure *measure)
-{ 
-  if (measure == NULL) 
+{
+  if (measure == NULL)
     return;
   objnode * theobjs = measure->objects;
   DenemoObject *prevobj = NULL, *theobj;
@@ -454,8 +499,8 @@ calculatebeamsandstemdirs (DenemoMeasure *measure)
   gint beamgroup_number = 0;
   gint beamgroup_highest = 0;
   gint beamgroup_lowest = 0;
-  
-  
+
+
   gboolean isbeambreak;
   gint  theclef = measure->clef->type;
   gint  thetime1 = measure->timesig->time1;
@@ -464,7 +509,7 @@ calculatebeamsandstemdirs (DenemoMeasure *measure)
   gint next_clef = theclef;      /* Useful for when a clef intrudes
                                    mid-beamgroup */
   gint next_stem_directive = thestem_directive;
-  
+
   if (theobjs==NULL)
     return;
 #if 0
@@ -591,7 +636,7 @@ calculatebeamsandstemdirs (DenemoMeasure *measure)
 #define ACCS_TOO_CLOSE 10
 /**
  * This function offsets accidentals that are near to each
- * other on the same chord.  
+ * other on the same chord.
  */
 void
 set_accidental_positions (DenemoObject * the_chord)
@@ -660,7 +705,7 @@ set_accidental_positions (DenemoObject * the_chord)
  */
 void
 showwhichaccidentals (objnode * theobjs)
-{ 
+{
   if(theobjs==NULL) return;
   gint curkey;
   gint * initialaccs;
@@ -683,11 +728,11 @@ showwhichaccidentals (objnode * theobjs)
 
   memcpy (ret, initialaccs, SEVENGINTS);
   memcpy (whatpersisted, initialaccs, SEVENGINTS);
-  
+
   for (curobjnode = theobjs; curobjnode; curobjnode = curobjnode->next)
     {
       theobj = (DenemoObject *) curobjnode->data;
-      
+
       if (theobj->type == CHORD)
         {
           ((chord *) theobj->object)->hasanacc = FALSE;
@@ -727,8 +772,8 @@ showwhichaccidentals (objnode * theobjs)
                 thetone->showaccidental = ((chord *) theobj->object)->hasanacc = TRUE;
               else
                 thetone->showaccidental = FALSE;
-                
-                
+
+
               // FIXME - you should use a script to apply these directives & set hasnacc with that.
               if (thetone->directives && ((DenemoDirective *) thetone->directives->data)->postfix && (*((DenemoDirective *) thetone->directives->data)->postfix->str == '!' || *((DenemoDirective *) thetone->directives->data)->postfix->str == '?'))
                 thetone->showaccidental = ((chord *) theobj->object)->hasanacc = (*((DenemoDirective *) thetone->directives->data)->postfix->str == '?') ? DENEMO_CAUTIONARY : DENEMO_REMINDER;
@@ -746,15 +791,15 @@ showwhichaccidentals (objnode * theobjs)
             theobj->minpixelsalloted = draw_key (NULL, 0, 0, ((keysig *) theobj->object)->number, curkey, 0, FALSE, (keysig *) theobj->object);
             curkey = ((keysig *) theobj->object)->number;
         }
-    
+
     }                           /* End object loop */
   //memcpy (initialaccs, ret, SEVENGINTS);
-  
+
 }
 
 /**
  *  Force and accidental to be shown on the score.
- * 
+ *
  * @param theobj the DenemoObject to force the accidential on
  */
 void
