@@ -138,6 +138,9 @@ const gchar *get_executable_dir (void);
 gchar *get_project_dir (void);
 const gchar *get_local_dir (DenemoDirectory dir);
 gchar *get_system_dir (DenemoDirectory dir);
+
+void copy_files (gchar *source_dir, gchar *dest_dir);//copies all files in source_dir to dest_dir creating the latter if need be
+
 void kill_process (GPid pid);
 
 gchar *music_font (gchar * str);
@@ -147,6 +150,7 @@ void score_status (DenemoProject * gui, gboolean change);
 void write_status (DenemoProject * gui);
 gboolean confirm (gchar * primary, gchar * secondary);
 gboolean choose_option (gchar * title, gchar * primary, gchar * secondary);
+gint choose_option_or_cancel (gchar * title, gchar * primary, gchar * secondary, gboolean cancel_button);
 void nullify_gstring (GString ** s);
 gchar *choose_file (gchar * title, gchar * startdir, GList * extensions);
 gchar *string_dialog_entry (DenemoProject * gui, gchar * title, gchar * instruction, gchar * initial_value);
@@ -295,6 +299,7 @@ typedef enum
   KeyPlusMouse = 3
 } DenemoShortcutType;
 void initialize_keystroke_help (void);
+void init_gdk_cursors (void);
 void KeyStrokeAwait (gchar * first_keypress);
 void KeyStrokeDecline (gchar * first_keypress);
 void KeyStrokeShow (gchar * str, gint command_idx, DenemoShortcutType type);
