@@ -32,7 +32,7 @@
 #define EXCL_WIDTH 3
 #define EXCL_HEIGHT 13
 #define SAMPLERATE (44100) /* arbitrary large figure used if no audio */
-static GdkPixbuf *StaffPixbuf, *StaffPixbufSmall, *StaffGoBack, *StaffGoForward;
+static GdkPixbuf *StaffPixbuf, *StaffPixbufSmall;
 static DenemoObject *Startobj, *Endobj;
 static gboolean layout_needed = TRUE;   //Set FALSE when further call to draw_score(NULL) is not needed.
 static GList *MidiDrawObject;/* a chord used for drawing MIDI recorded notes on the score */
@@ -80,9 +80,8 @@ create_tool_pixbuf (void)
 {
   GtkWidget *widget = gtk_button_new ();
   StaffPixbuf = gtk_widget_render_icon (widget, GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_BUTTON, "denemo");
-  StaffPixbufSmall = gtk_widget_render_icon (widget, GTK_STOCK_PROPERTIES, GTK_ICON_SIZE_MENU, "denemo");
-  StaffGoBack = gtk_widget_render_icon (widget, GTK_STOCK_GO_BACK, GTK_ICON_SIZE_BUTTON, "denemo");
-  StaffGoForward = gtk_widget_render_icon (widget, GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON, "denemo");
+  StaffPixbufSmall = gtk_widget_render_icon (widget, GTK_STOCK_GO_FORWARD, GTK_ICON_SIZE_BUTTON, "denemo");//something for highlighting!
+  
 }
 
 
@@ -267,16 +266,32 @@ draw_object (cairo_t * cr, objnode * curobj, gint x, gint y, DenemoProject * gui
         cairo_fill (cr);
         cairo_restore (cr);
       }
+  if (cr && (!Denemo.hovering_over_margin_up)
+         && (!Denemo.hovering_over_margin_down)
+         && (!Denemo.hovering_over_partname)
+         && (!Denemo.hovering_over_clef)
+         && (!Denemo.hovering_over_timesig)
+         && (!Denemo.hovering_over_keysharpen)
+         && (!Denemo.hovering_over_keyflatten)
+         && (!Denemo.hovering_over_movement)
+         && (!Denemo.hovering_over_right_arrow) 
+         && (!Denemo.hovering_over_left_arrow)) //this is the hovered over object being given a colored background
+    if ((Denemo.object_hovering_over==curobj) && ((si->currentobject != curobj) || ((si->currentobject == curobj) && si->cursor_appending)))
+      {
+        cairo_save (cr);
+  // if curobj->next is NULL then we may be hovering over the barline we need to detect this in mousing.c and set object_hovering_over to a dummy barline object???, then draw here     
+        cairo_set_source_rgba (cr, 0.5, 0.5, 0.9, 0.3);
+        cairo_arc (cr, x + mudelaitem->x +  mudelaitem->minpixelsalloted/2, y + 20, mudelaitem->minpixelsalloted, 0.0, 2 * M_PI);
+        cairo_fill (cr);
+        cairo_set_source_rgba (cr, 0.2, 0.2, 0.9, 1);
+        cairo_arc (cr, x + mudelaitem->x +  mudelaitem->minpixelsalloted/2, y + 20, mudelaitem->minpixelsalloted, 0.0, 2 * M_PI);
+        cairo_stroke (cr);
+          
+        
+        cairo_restore (cr);
+      }
+  
 
-
-// if (Denemo.project->movement->playingnow)
- //   g_print("%p %p %f %f %f\n", Denemo.project->movement->playingnow, mudelaitem, Denemo.project->movement->playhead,  mudelaitem->earliest_time, mudelaitem->latest_time );
-
-  // draw playhead as (yellowish now) blue background
- //if (Denemo.project->movement->playingnow == mudelaitem)
-//  if (Denemo.project->movement->playingnow && (Denemo.project->movement->playhead >= mudelaitem->earliest_time) &&
-//        (Denemo.project->movement->playhead < mudelaitem->latest_time)) falls through a gap!!!!
-//  if (Denemo.project->movement->playingnow && (Denemo.project->movement->playhead >= mudelaitem->earliest_time))
     if(Denemo.project->movement->playingnow && itp->highlight_next_note && (((Denemo.project->movement->playhead < mudelaitem->latest_time))))
         {
             itp->highlight_next_note = FALSE;
@@ -999,12 +1014,17 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
             draw_timesig (cr, x + 5, y, itp->time1, itp->time2, thestaff->leftmost_timesig);
           else
             {
-              guint width = gdk_pixbuf_get_width (GDK_PIXBUF (StaffGoBack));
-              guint height = gdk_pixbuf_get_height (GDK_PIXBUF (StaffGoBack));
               cairo_save (cr);
-              gdk_cairo_set_source_pixbuf (cr, GDK_PIXBUF (StaffGoBack), x, y);
-              cairo_rectangle (cr, x, y, width, height);
-              cairo_fill (cr);
+              if (Denemo.hovering_over_left_arrow)
+                {
+                    cairo_rectangle (cr, x, y, 30, 40);
+                    cairo_stroke (cr);
+                    cairo_set_source_rgb (cr, 0.7, 1.0, 0.7);
+                    cairo_rectangle (cr, x, y, 30, 40);
+                    cairo_fill (cr);
+                }
+              cairo_set_source_rgb (cr, 0.1, 0.2, 1);
+              drawtext_cr  (cr, "<", x, y + 30, 42.0);
               cairo_restore (cr);
             }
         }
@@ -1033,32 +1053,39 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
       if (!itp->line_end)
         {
           gint staffname_offset = (thestaff->voicecontrol & DENEMO_PRIMARY) ? 26 : 12;
-
+          gboolean color = (Denemo.hovering_over_partname && (si->currentstaffnum == itp->staffnum));
            if (si->leftmeasurenum == 1)//make a button of it if measure 1 is leftmost
              {
-              drawnormaltext_cr (cr, thestaff->denemo_name->str, gui->leftmargin /*KEY_MARGIN */ , y - staffname_offset + 10);
-              if (thestaff->subpart)
-                drawnormaltext_cr (cr, thestaff->subpart->str, gui->leftmargin +20/*KEY_MARGIN */ , y - staffname_offset + 20);
+             
               cairo_save (cr);
-              cairo_set_source_rgba (cr, 0.2, 0.8, 0.4, 0.4);
-              cairo_rectangle (cr, gui->leftmargin, y - staffname_offset - 0, 30, 12);
+              cairo_set_source_rgb (cr, 0.8, color?1:0.8, 0.8);
+
+              cairo_rectangle (cr, gui->leftmargin + 5, y - staffname_offset - 1, 90, 15);
               cairo_fill (cr);
-              cairo_set_source_rgba (cr, 0.0, 0.8, 0.0, 1);
-              cairo_rectangle (cr, gui->leftmargin, y - staffname_offset - 0, 30, 12);
-              cairo_stroke (cr);
+
+              
+              cairo_set_source_rgb (cr, 0.0, 0.0, 0.0);
+              if (color)
+                {
+                    cairo_rectangle (cr, gui->leftmargin + 5, y - staffname_offset - 2, 90, 16);
+                    cairo_stroke (cr);
+                }
+              drawnormaltext_cr (cr, thestaff->denemo_name->str, gui->leftmargin /*KEY_MARGIN */ + 5 , y - staffname_offset + 10);
+              if (thestaff->subpart)
+                drawnormaltext_cr (cr, thestaff->subpart->str, gui->leftmargin +20/*KEY_MARGIN */ , y - staffname_offset + 24);
               cairo_restore(cr);
              }
            else
              {
-              drawnormaltext_cr (cr, thestaff->denemo_name->str, gui->leftmargin - 10 /*KEY_MARGIN */ , y - staffname_offset + 10);
+              drawnormaltext_cr (cr, thestaff->denemo_name->str, gui->leftmargin - 10 /*KEY_MARGIN */ + 5 , y - staffname_offset + 10);
               if (thestaff->subpart)
-                drawnormaltext_cr (cr, thestaff->subpart->str, gui->leftmargin + 20 /*KEY_MARGIN */ , y - staffname_offset + 20);
+                drawnormaltext_cr (cr, thestaff->subpart->str, gui->leftmargin + 20 /*KEY_MARGIN */ , y - staffname_offset + 24);
              }
             if(thestaff->hasfakechords)  drawnormaltext_cr (cr, _("Chord Symbols"), gui->leftmargin - 10 /*KEY_MARGIN */ , y - staffname_offset + 20 + 2 * STAFF_HEIGHT);
             if(thestaff->hasfigures)  drawnormaltext_cr (cr, _("Figured Bass"), gui->leftmargin - 10 /*KEY_MARGIN */ , y - staffname_offset + 20 + 2 * STAFF_HEIGHT);
             { cairo_save (cr);
-              cairo_set_source_rgb (cr, 1, 0.4, 0.4);
-              if(thestaff->hidden)  drawlargetext_cr (cr, _("Hidden when not the current staff."), gui->leftmargin +55, y - staffname_offset + 5 + 2 * STAFF_HEIGHT);
+              cairo_set_source_rgba (cr, 0.1, 0.6, 0.1, 0.5);
+              if(thestaff->hidden)  drawnormaltext_cr (cr, _("Hidden when not the current staff."), gui->leftmargin +55, y - staffname_offset - 5 + 2 * STAFF_HEIGHT);
               cairo_restore(cr);
             }
         }
@@ -1225,14 +1252,19 @@ draw_staff (cairo_t * cr, staffnode * curstaff, gint y, DenemoProject * gui, str
       if (itp->measurenum > si->rightmeasurenum)
         if (!itp->end)
           {
-            guint width = gdk_pixbuf_get_width (GDK_PIXBUF (StaffGoForward));
-            guint height = gdk_pixbuf_get_height (GDK_PIXBUF (StaffGoForward));
-            cairo_save (cr);
-            gint xx = get_widget_width (Denemo.scorearea) / gui->movement->zoom - width;
-            gdk_cairo_set_source_pixbuf (cr, GDK_PIXBUF (StaffGoForward), xx, y);
-            cairo_rectangle (cr, xx, y, width, height);
-            cairo_fill (cr);
-            cairo_restore (cr);
+             cairo_save (cr);
+             gint xx = get_widget_width (Denemo.scorearea) / gui->movement->zoom - 20;
+              if (Denemo.hovering_over_right_arrow)
+                {
+                    cairo_rectangle (cr, xx, y, 30, 40);
+                    cairo_stroke (cr);
+                    cairo_set_source_rgb (cr, 0.7, 1.0, 0.7);
+                    cairo_rectangle (cr, xx, y, 30, 40);
+                    cairo_fill (cr);
+                }
+              cairo_set_source_rgb (cr, 0.1, 0.2, 1);
+              drawtext_cr  (cr, ">", xx, y + 30, 42.0);
+              cairo_restore (cr);
           }
 
   if (cr)
@@ -1398,6 +1430,8 @@ draw_score (cairo_t * cr)
   itp.currentframe = (get_playback_time()/get_playback_speed())*(si->recording?si->recording->samplerate:SAMPLERATE);
   itp.allow_duration_error = FALSE;
 
+  if (Denemo.hidden_staff_heights)  g_list_free (Denemo.hidden_staff_heights);
+  Denemo.hidden_staff_heights = NULL;
   if (gui->movement->smf)
     {
       itp.startobj = Startobj;
@@ -1416,6 +1450,22 @@ draw_score (cairo_t * cr)
     cairo_scale (cr, gui->movement->zoom, gui->movement->zoom);
   if (cr)
     cairo_translate (cr, 0.5, 0.5);
+    /*draw a flag in the corner for accessing whole-movement settings */
+ if (cr)
+        {
+         if (Denemo.hovering_over_movement)
+                {
+                    cairo_set_source_rgb (cr, 0.7, 1.0, 0.7);
+                    cairo_rectangle (cr, 0, 0, 25, 25);
+                    cairo_fill (cr);
+                }
+            cairo_set_source_rgb (cr, 0, 0, 0);
+            cairo_rectangle (cr, 0, 0, 25, 25);
+            cairo_stroke (cr);
+ 
+            drawlargetext_cr (cr, "⚐", 2, 20);
+
+        }
 
  if (cr && (si->leftmeasurenum == 1))
   {
@@ -1508,37 +1558,48 @@ draw_score (cairo_t * cr)
       g_slist_free (itp.hairpin_stack);//clear any cresc or dim started but not finished; these can just be off-screen, they need not be in error.
       itp.hairpin_stack = NULL;
       if(cr) if (staff->hidden && (si->currentstaffnum != itp.staffnum))
-      {
-
-
-        cairo_save (cr);
-        cairo_set_source_rgba (cr, 0.0, 0.5, 0.5, 0.6);
-
-        if (itp.staffnum == si->top_staff)
+          {
+            static GString *hidden_text;
+            if (hidden_text == NULL) 
+                hidden_text = g_string_new (_("Hidden "));
+            static gint height;
+            gint top_height = 10; //height to put line indicating hidden staff when it is the top staff
+            if (height == 0)
+                height = (itp.staffnum == si->top_staff)? top_height :y - 35;
+            Denemo.hidden_staff_heights = g_list_append (Denemo.hidden_staff_heights, GINT_TO_POINTER (height));   
+            g_string_append_printf (hidden_text, "%s ", staff->denemo_name->str);
             {
-                //cairo_rectangle (cr, 0, 5, 50, 3);
-                cairo_rectangle (cr, 200, 5, get_widget_width (Denemo.scorearea) / Denemo.project->movement->zoom - 120, 3);
-                cairo_fill (cr);
-                cairo_set_source_rgba (cr, 1.0, 0.5, 0.5, 1);
-                gchar *text = g_strdup_printf ("%s (%s)", staff->denemo_name->str, _( "Hidden"));
-                drawnormaltext_cr (cr, text, 80, 10);
-                g_free (text);
-            }
-        else {
-                cairo_rectangle (cr, 20, y - 35, get_widget_width (Denemo.scorearea) / Denemo.project->movement->zoom - 120, 3);
-                cairo_fill (cr);
-                cairo_set_source_rgba (cr, 1.0, 0.5, 0.5, 1);
-                drawlargetext_cr (cr, staff->denemo_name->str,  80, itp.staffnum == si->top_staff? 15 : y - 35);
-                drawlargetext_cr (cr, _("Hidden"), 80, y - 10);
-            }
-
-
-
-        cairo_restore (cr);
-        continue;
-      }
+                DenemoStaff *nextstaff = curstaff->next ? ((DenemoStaff *) curstaff->next->data) : NULL;
+                if ((nextstaff==NULL) || ((!nextstaff->hidden) || (si->currentstaffnum == (1 + itp.staffnum))))
+                    {
+                        cairo_save (cr);
+                        cairo_set_source_rgba (cr, 0.0, 0.5, 0.5, 0.6);
+                        
+                        if (height == top_height) //the top and possibly other staffs are hidden
+                            {
+                                cairo_rectangle (cr, 300, 5, get_widget_width (Denemo.scorearea) / Denemo.project->movement->zoom - 120, 3);
+                                cairo_fill (cr);
+                                cairo_set_source_rgba (cr, 1.0, 0.5, 0.5, 1);
+                                drawnormaltext_cr (cr, hidden_text->str, 120, height);
+                                
+                            }
+                        else 
+                            {
+                                cairo_rectangle (cr, 20, height, get_widget_width (Denemo.scorearea) / Denemo.project->movement->zoom - 120, 3);
+                                cairo_fill (cr);
+                                cairo_set_source_rgba (cr, 1.0, 0.5, 0.5, 1);
+                                drawlargetext_cr (cr,hidden_text->str,  80, y - 35);
+                               // drawlargetext_cr (cr, _("Hidden"), 80, y - 10);
+                            }
+                       g_string_assign (hidden_text, _("Hidden "));
+                       height = 0;
+                       cairo_restore (cr);
+                    }
+                }
+            continue;
+          }
       itp.verse = verse_get_current_view (staff);
-      GdkPixbuf *StaffDirectivesPixbuf = (si->currentstaffnum == itp.staffnum) ? StaffPixbuf : StaffPixbufSmall;
+      GdkPixbuf *StaffDirectivesPixbuf = (Denemo.hovering_over_margin_up) ? StaffPixbuf : StaffPixbufSmall;
       if (si->currentstaffnum == itp.staffnum)
         y += staff_transition_offset ();
 
@@ -1558,43 +1619,35 @@ draw_score (cairo_t * cr)
       itp.in_highy = highy, itp.in_lowy = lowy;
       itp.highy = 0;            //do not pass on extra_space from one staff to the next
       if (flip_count <= 0)
-        if (cr)
+      if (cr)
           {
             cairo_save (cr);
-            cairo_set_source_rgb (cr, 0.5, 0.5, 1.0);
-            cairo_rectangle (cr, 0, y, 20/*BASIC LEFT_MARGIN*/, STAFF_HEIGHT /*staff edit */ );
+            cairo_set_source_rgb (cr, 0.7, 0.7, 0.7);
+            cairo_rectangle (cr, 0, y, 20/*BASIC LEFT_MARGIN*/, STAFF_HEIGHT);
             cairo_fill (cr);
-            //cairo_restore (cr);
-
-
-            //  {
-
-                guint width = gdk_pixbuf_get_width (GDK_PIXBUF (StaffDirectivesPixbuf));
-                guint height = gdk_pixbuf_get_height (GDK_PIXBUF (StaffDirectivesPixbuf));
-              // cairo_save (cr);
-                gdk_cairo_set_source_pixbuf (cr, GDK_PIXBUF (StaffDirectivesPixbuf), 0, y);
-                cairo_rectangle (cr, 0, y, width, height);
-                cairo_fill (cr);
-
-                cairo_set_source_rgb (cr, 0, 0, 0);
-                cairo_rectangle (cr, 0, y, width, height);
-                cairo_stroke (cr);
-
-                cairo_set_source_rgb (cr, 0, 0, 0);
-                gint staffnumber = 1 + g_list_position (si->thescore,curstaff);
-                gchar *number = g_strdup_printf ("%d", staffnumber);
-                if(staffnumber>9)
-                    drawnormaltext_cr (cr, number, 0, y + STAFF_HEIGHT - 2);
-                else
-                    drawlargetext_cr (cr, number, 0, y + STAFF_HEIGHT - 2);
-                g_free (number);
-
-                cairo_restore (cr);
-
-           //  }
-
-
-
+            cairo_set_source_rgb (cr, 0.7, 1.0, 0.7);
+            if (Denemo.hovering_over_margin_up && (si->currentstaffnum == itp.staffnum))
+                cairo_rectangle (cr, 0, y, 20/*BASIC LEFT_MARGIN*/, STAFF_HEIGHT/2 /*staff edit */ ), cairo_fill (cr);
+            else if (Denemo.hovering_over_margin_down && (si->currentstaffnum == itp.staffnum))
+                cairo_rectangle (cr, 0, y + STAFF_HEIGHT/2, 20/*BASIC LEFT_MARGIN*/, STAFF_HEIGHT/2 /*staff edit */ ), cairo_fill (cr);;
+            
+           
+            
+            cairo_set_source_rgb (cr, 0, 0, 0);
+            if (Denemo.hovering_over_margin_up && (si->currentstaffnum == itp.staffnum))
+                cairo_rectangle (cr, 0, y, 20/*BASIC LEFT_MARGIN*/, STAFF_HEIGHT/2 /*staff edit */ ),cairo_stroke (cr);
+           else if (Denemo.hovering_over_margin_down && (si->currentstaffnum == itp.staffnum))
+                cairo_rectangle (cr, 0, y + STAFF_HEIGHT/2, 20/*BASIC LEFT_MARGIN*/, STAFF_HEIGHT/2 /*staff edit */ ), cairo_stroke (cr);
+            
+            gint staffnumber = 1 + g_list_position (si->thescore,curstaff);
+            gchar *number = g_strdup_printf ("%d", staffnumber);
+            if(staffnumber>9)
+                drawnormaltext_cr (cr, number, 0, y + STAFF_HEIGHT - 2);
+            else
+                drawlargetext_cr (cr, number, 0, y + STAFF_HEIGHT - 2);
+            g_free (number);
+            drawnormaltext_cr (cr, "⚐", 5, y + STAFF_HEIGHT/2 - 6);
+            cairo_restore (cr);
 
             if (si->leftmeasurenum == 1 && !(staff->voicecontrol & DENEMO_SECONDARY))
               {
@@ -1603,29 +1656,40 @@ draw_score (cairo_t * cr)
                 gint cmajor = key ? 0 : 5;      //allow some area for keysig in C-major
                 cairo_save (cr);
 
-                cairo_set_source_rgb (cr, 0.7, 0.7, 0.7);
-                cairo_rectangle (cr, gui->leftmargin, y, (gui->leftmargin+35) - gui->leftmargin - cmajor, STAFF_HEIGHT);  /*clef edit */
-
+                cairo_set_source_rgb (cr, 0.7, Denemo.hovering_over_clef?1.0:0.7, 0.7);
+                if (si->currentstaffnum == itp.staffnum)
+                    cairo_rectangle (cr, gui->leftmargin, y, (gui->leftmargin+35) - gui->leftmargin - cmajor, STAFF_HEIGHT);  /*clef edit */
+                cairo_fill (cr);
+                
+                cairo_set_source_rgb (cr, 0.7, Denemo.hovering_over_timesig?1.0:0.7, 0.7);
                 cairo_rectangle (cr, (gui->leftmargin+35) + key + cmajor, y, SPACE_FOR_TIME - cmajor, STAFF_HEIGHT);      /*timesig edit */
                 cairo_fill (cr);
 
-                cairo_set_source_rgb (cr, 0.5, 0.5, 1.0);
+                cairo_set_source_rgba (cr, Denemo.hovering_over_keysharpen?0.0:0.2, Denemo.hovering_over_keysharpen?0.0:0.2, Denemo.hovering_over_keysharpen?1.0:0.9, 0.5);
                 cairo_rectangle (cr, (gui->leftmargin+35) - cmajor, y, key + 2 * cmajor, STAFF_HEIGHT / 2);       /*keysig sharpen edit */
                 cairo_fill (cr);
-                cairo_set_source_rgb (cr, 0, 0, 1);
-                cairo_set_line_width (cr, 3);
-                cairo_rectangle (cr, (gui->leftmargin+35) - cmajor, y, key + 2 * cmajor, STAFF_HEIGHT / 2);
-                cairo_stroke (cr);
+                
+                
+                if (Denemo.hovering_over_keysharpen)
+                    {
+                    cairo_set_source_rgb (cr, 0, 0, 0);
+                    cairo_set_line_width (cr, 3);
+                    cairo_rectangle (cr, (gui->leftmargin+35) - cmajor -2 , y-2, key + 2 * cmajor+4, STAFF_HEIGHT / 2 +4);
+                    cairo_stroke (cr);
+                    }
 
+                //cairo_set_source_rgb (cr, 1, 0.5, 0.5);
+                cairo_set_source_rgba (cr, Denemo.hovering_over_keyflatten?1.0:0.8, Denemo.hovering_over_keyflatten?0.0:0.4, Denemo.hovering_over_keyflatten?0.0:0.4, 0.5);
 
-                cairo_set_source_rgb (cr, 1, 0.5, 0.5);
                 cairo_rectangle (cr, (gui->leftmargin+35) - cmajor, y + STAFF_HEIGHT / 2, key + 2 * cmajor, STAFF_HEIGHT / 2);    /*keysig flatten edit */
                 cairo_fill (cr);
-                cairo_set_source_rgb (cr, 1, 0, 0);
-                cairo_set_line_width (cr, 3);
-                cairo_rectangle (cr, (gui->leftmargin+35) - cmajor, y + STAFF_HEIGHT / 2, key + 2 * cmajor, STAFF_HEIGHT / 2);
-                cairo_stroke (cr);
-
+                if (Denemo.hovering_over_keyflatten)
+                    {
+                    cairo_set_source_rgb (cr, 0, 0, 0);
+                    cairo_set_line_width (cr, 3);
+                    cairo_rectangle (cr, (gui->leftmargin+35) - cmajor -2, y + STAFF_HEIGHT / 2 -2, key + 2 * cmajor +4, STAFF_HEIGHT / 2 +4);
+                    cairo_stroke (cr);
+                    }
 
 
                 cairo_restore (cr);
