@@ -64,6 +64,7 @@ dnm_setinitialtimesig (DenemoMovement * si, DenemoStaff * curstaffstruct, gint t
 {
   staffnode *curstaff;
   take_snapshot ();
+  signal_structural_change (Denemo.project);
   if (time1 && time2 && ispow2 (time2))
     {
       if (all_staves)
@@ -88,7 +89,7 @@ dnm_setinitialtimesig (DenemoMovement * si, DenemoStaff * curstaffstruct, gint t
 
 
 /**
- * Insert time sig change on either a single staff or across the
+ * Insert time sig change across the
  * entire score.
  */
 static void
@@ -101,7 +102,7 @@ insert_timesig (DenemoMovement * si, DenemoStaff * curstaffstruct, gint time1, g
   gboolean replacing = FALSE;   /* if we don't use this trick, anomalous
                                  * stuff can happen when replacing a time
                                  * signature */
-
+  take_snapshot ();
   for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
     {
       if (((DenemoStaff *) curstaff->data)->is_parasite)
